#
# spec file for package scim
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%endif
%define build_qt4 0%{?suse_version} <= 1500 && 0%{?sle_version} < 150300

Name:           scim
Version:        1.4.18
Release:        bp154.2.102
Summary:        Smart Chinese/Common Input Method platform
License:        LGPL-2.1-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/scim-im/scim
Source:         %{name}-%{version}.tar.xz
Source1:        xim.d-scim
Source2:        scim.config
Source3:        macros.scim
Source99:       baselibs.conf
Patch1:         configs.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  x11-tools
BuildRequires:  xz
%if %{build_qt4}
BuildRequires:  libqt4-devel
%endif
Requires:       scim-gtk = %{version}
Recommends:     scim-lang = %{version}
%if %{build_qt4}
Requires:       scim-qt4 = %{version}
%endif
# not SLE_12
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
BuildRequires:  libpng-tools
%endif
%if 0%{?suse_version} > 1130
BuildRequires:  gtk3-devel
Requires:       scim-gtk3 = %{version}
%endif

%description
SCIM is a developing platform to significantly reduce the difficulty of
input method development.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package gtk
Summary:        SCIM im module for gtk2
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Supplements:    packageand(scim:gtk2)
%if 0%{?sles_version} && 0%{?suse_version} != 1315
Requires(post): gtk2
Requires(postun): gtk2
%else
%{gtk2_immodule_requires}
%endif

%description gtk
This package contains SCIM im module for gtk2

%if 0%{?suse_version} > 1130
%package gtk3
Summary:        SCIM im module for gtk3
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Supplements:    packageand(scim:gtk3)
%{gtk3_immodule_requires}

%description gtk3
This package contains SCIM im module for gtk3
%endif

%if %{build_qt4}
%package qt4
Summary:        SCIM im module for qt4
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Supplements:    packageand(scim:libqt4)

%description qt4
This package contains SCIM im module for qt4
%endif

%lang_package

%prep
%setup -q
%patch1 -p1
UTF_8_LOCALES=$(locale -a | grep utf8 | perl -p -e "s/utf8/UTF-8/; s/\n/,/; " | perl -p -e "s/,$//")
perl -pi -e "s/\/SupportedUnicodeLocales =.*/\/SupportedUnicodeLocales = $UTF_8_LOCALES/"  configs/global
# hack to fix incompatibility of gtk-query-immodules-2.0 (bnc#845860)
%if 0%{?suse_version} < 1310
sed -i \
    -e's@\(gtk-query-immodules-2.0-64\) --update-cache@\1 > <prefix>%{_sysconfdir}/gtk-2.0/gtk64.immodules@g' \
    -e's@\(gtk-query-immodules-2.0\) --update-cache@\1 > <prefix>%{_sysconfdir}/gtk-2.0/gtk.immodules@g' \
    %{_sourcedir}/baselibs.conf
%endif

%build
./bootstrap
%configure\
	--libexecdir=%{_libexecdir}/scim-1.0\
%if 0%{?suse_version} > 1130
        --with-gtk3-im-module-dir=%{_libdir}/gtk-3.0/3.0.0/immodules\
        --with-gtk-version=3\
%endif
	--enable-gtk2-immodule\
%if %{build_qt4}
        --enable-qt4-immodule\
%endif
	--disable-static\
	--enable-debug\
	--enable-ld-version-script
make %{?_smp_mflags} top_builddir=$(pwd)
# build documentation:
make %{?_smp_mflags} -C docs html

%install
make DESTDIR=%{buildroot} top_builddir=$(pwd) install
find %{buildroot} -type f -name "*.la" -delete -print

# install configuration files
mkdir -p %{buildroot}%{_distconfdir}/X11/xim.d/
install -m 644 %{SOURCE1} %{buildroot}%{_distconfdir}/X11/xim.d/scim

# install symlinks in /etc/X11/xim.d/$lang for all languages
# where SCIM might be useful:
PRIORITY=50
pushd %{buildroot}%{_distconfdir}/X11/xim.d/
    for lang in am ar as bn el fa gu he hi hr ja ka kk kn ko lo ml my \
		pa ru sk vi zh_TW zh_CN zh_HK zh_SG \
		de fr it es nl cs pl da nn nb fi en sv
    do
        mkdir $lang
	pushd $lang
            ln -s ../scim $PRIORITY-scim
	popd
    done
popd

install -m 755 %{SOURCE2} %{buildroot}%{_datadir}/scim
%find_lang scim
%suse_update_desktop_file scim-setup System SystemSetup

# own _scim_tabledir
install -d %{buildroot}%{_datadir}/scim/tables

# install macro.scim
mkdir -p %{buildroot}%{_rpmmacrodir}
install -m 644 %{SOURCE3} %{buildroot}%{_rpmmacrodir}/

# not SLE_12
%if 0%{?suse_version} >= 1310 && 0%{?suse_version} != 1315
%png_fix %{buildroot}%{_datadir}/%{name}/icons/menu.png
%endif

%fdupes %{buildroot}

%post
/sbin/ldconfig
# Update KeyboardLayout
%{_datadir}/scim/scim.config

%postun -p /sbin/ldconfig
%post gtk
/sbin/ldconfig
%if 0%{?sles_version} && 0%{?suse_version} != 1315
%if "%{_lib}" == "lib64"
	%{_bindir}/gtk-query-immodules-2.0-64 > %{_sysconfdir}/gtk-2.0/gtk64.immodules
%else
	%{_bindir}/gtk-query-immodules-2.0 > %{_sysconfdir}/gtk-2.0/gtk.immodules
%endif
%else
%{gtk2_immodule_post}
%endif

%postun gtk
/sbin/ldconfig
%if 0%{?sles_version} && 0%{?suse_version} != 1315
if [ $1 -eq 0 ] ; then
%if "%{_lib}" == "lib64"
	%{_bindir}/gtk-query-immodules-2.0-64 > %{_sysconfdir}/gtk-2.0/gtk64.immodules
%else
	%{_bindir}/gtk-query-immodules-2.0 > %{_sysconfdir}/gtk-2.0/gtk.immodules
%endif
fi
%else
%{gtk2_immodule_postun}
%endif

%if 0%{?suse_version} > 1130
%post gtk3
#Add icons to gnome3 panel
TARGET="%{_datadir}/gnome-shell/js/ui/statusIconDispatcher.js"
if [ -f $TARGET ] && [ ! -f $TARGET-scim ] ; then
mv $TARGET $TARGET-scim
sed "/^const STANDARD_TRAY_ICON_IMPLEMENTATIONS/a \    'scim-panel-gtk': 'input-method'," $TARGET-scim > $TARGET
fi
%{gtk3_immodule_post}

%postun gtk3
/sbin/ldconfig
%{gtk3_immodule_postun}
%endif

%files
%license COPYING
%doc AUTHORS README ChangeLog TODO
%{_distconfdir}/X11/xim.d
%{_rpmmacrodir}/macros.scim
%dir %{_sysconfdir}/scim
%config %{_sysconfdir}/scim/config
%config %{_sysconfdir}/scim/global
%{_bindir}/scim
%{_bindir}/scim-config-agent
%{_bindir}/scim-im-agent
%{_bindir}/scim-setup
%{_libdir}/scim-1.0/scim-helper-launcher
%{_libdir}/scim-1.0/scim-helper-manager
%{_libdir}/scim-1.0/scim-launcher
%{_libdir}/scim-1.0/scim-panel-gtk
%{_datadir}/scim
%dir %{_datadir}/scim/tables
%{_datadir}/pixmaps/scim-setup.png
%{_datadir}/applications/scim-setup.desktop
%{_datadir}/control-center-2.0
%{_libdir}/libscim-1.0.so.8
%{_libdir}/libscim-1.0.so.8.2.6
%{_libdir}/libscim-gtkutils-1.0.so.8
%{_libdir}/libscim-gtkutils-1.0.so.8.2.6
%{_libdir}/libscim-x11utils-1.0.so.8
%{_libdir}/libscim-x11utils-1.0.so.8.2.6
%dir %{_libdir}/scim-1.0
%dir %{_libdir}/scim-1.0/1.4.0
%dir %{_libdir}/scim-1.0/1.4.0/Config
%dir %{_libdir}/scim-1.0/1.4.0/Filter
%dir %{_libdir}/scim-1.0/1.4.0/FrontEnd
%dir %{_libdir}/scim-1.0/1.4.0/Helper
%dir %{_libdir}/scim-1.0/1.4.0/IMEngine
%dir %{_libdir}/scim-1.0/1.4.0/SetupUI
%{_libdir}/scim-1.0/1.4.0/Config/simple.so
%{_libdir}/scim-1.0/1.4.0/Config/socket.so
%{_libdir}/scim-1.0/1.4.0/Filter/sctc.so
%{_libdir}/scim-1.0/1.4.0/FrontEnd/socket.so
%{_libdir}/scim-1.0/1.4.0/FrontEnd/x11.so
%{_libdir}/scim-1.0/1.4.0/Helper/setup.so
%{_libdir}/scim-1.0/1.4.0/IMEngine/rawcode.so
%{_libdir}/scim-1.0/1.4.0/IMEngine/socket.so
%{_libdir}/scim-1.0/1.4.0/SetupUI/aaa-frontend-setup.so
%{_libdir}/scim-1.0/1.4.0/SetupUI/aaa-imengine-setup.so
%{_libdir}/scim-1.0/1.4.0/SetupUI/panel-gtk-setup.so

%files gtk
%{_libdir}/gtk-2.0/2.10.0/immodules/im-scim.so

%if 0%{?suse_version} > 1130
%files gtk3
%{_libdir}/gtk-3.0/3.0.0/immodules/im-scim.so
%endif

%if %{build_qt4}
%files qt4
%{_libdir}/qt4/plugins/inputmethods/im-scim.so
%endif

%files devel
%doc docs/html
%doc docs/developers
%{_libdir}/libscim-1.0.so
%{_libdir}/libscim-gtkutils-1.0.so
%{_libdir}/libscim-x11utils-1.0.so
%{_libdir}/pkgconfig/scim.pc
%{_libdir}/pkgconfig/scim-gtkutils.pc
%{_libdir}/pkgconfig/scim-x11utils.pc
%{_includedir}/scim-1.0

%files lang -f %{name}.lang

%changelog
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move macros.scim from /etc/rpm to %%_rpmmacrodir (boo#1185657).
* Thu Dec 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not build the qt4 subpackage for Leap 15.3 or newer
  (boo#1179613).
* Thu Nov 26 2020 tiwai@suse.de
- Move the startup snippet to /usr/etc/X11/xim.d for TW
* Sat Apr 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Stop packaging the -qt4 plugin on openSUSE >= 1500.
  Qt4 is EOL and will not be available in future openSUSE releases.
- Run spec-cleaner.
* Mon Jul 31 2017 i@marguerite.su
- update version 1.4.18
  * define G_GNUC_BEGIN/END_IGNORE_DEPRECATIONS
  * fixed a no return in non void function error
  * (boo#1041268) FTBFS with GCC-7: invalid conversion
    from 'char' to 'const void*'
- changes in 1.4.17
  * lower the chance to clear config file
  * detect the num-lock mask as well
  * handle the fallback im-context correctly
  * correct the text/background colors of the preedit area for GTK >= 3
  * optimize all png files
  * add needed includedir to support out-of-srcdir building
  * fix the scim_string_view_draw() bug for GTK >= 3.20
- drop upstreamed patch:
  * scim-fix-no-return-in-non-void.patch
  * G_GNUC_BEGIN_IGNORE_DEPRECATIONS.patch
* Thu Sep 10 2015 i@marguerite.su
- Update to version 1.4.15+git20150804.187a1fd:
  * drop and ignore dotfiles
  * drop some empty files
  * disable subdir-objects
  * add manpages taken from debian
  * IMdkit: Track window property offsets correctly
  * disable setpwent. patch from openSUSE
  * add sharedmethod support
  * use reference-to-const for copy constructor to pass c++11
  * fix SCIM_DEBUG_AllMask to be unsigned
- refactored xim.d-scim
  * skim is not available, no need to conditional check any more
  * it should not be scim to set path for kde3
  * this is shipped w/ scim, no need to check existence
- baselibs.conf: no more scim-qt3
- drop patch: scim-disable-subdir-objects.patch, upstreamed
- drop patch: scim-no-setpwent.diff, upstreamed
- fix post/postun scripts
- remove unneeded conditionals which will be always built like
  gtk2/qt4-immodule, simple config and x11 frontend
- remove unneeded gnome_prefix macro
- remove unneeded provides/obsoletes, those packages are not in
  either SLE or openSUSE now.
- remove SLE_10 hacks
- add patch: G_GNUC_BEGIN_IGNORE_DEPRECATIONS.patch
  * define G_GNUC_BEGIN_IGNORE_DEPRECATIONS is undefined
- add macros.scim
* Sun Mar 22 2015 p.drouand@gmail.com
- Update to version 1.4.15
  * ChangeLog has not been updated for this release
- Update home project and download Url
- No hard dependencies for devel subpackage; let pkgconfig handles
  this
- Add pkgconfig build require
- Add autoconf build require; as the tarball is generated from git,
  the configure script has to be created at first
- Remove sle-11-gtk-widget-get-visible.patch; upstreamed
- Split out translation files
- Add scim-fix-no-return-in-non-void.patch
- Add scim-disable-subdir-objects.patch
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashism in scim.config script
* Fri Feb 14 2014 tiwai@suse.de
- Fix *-32bit post and postun calls for gtk-query-immodules-2 on
  openSUSE 13.1 and later (bnc#845860)
* Fri Feb 14 2014 tyang@suse.com
- fate #313546 Get rid of SuSEconfig.scim
  rename the SuSEconfig.scim into scim.config
* Tue Dec  3 2013 pgajdos@suse.com
- use png_fix macro [bnc#852862]
* Tue Jul 16 2013 coolo@suse.com
- remove qt3 support, long dead
* Tue Feb  5 2013 dimstar@opensuse.org
- Add scim to baselibs.conf: needed in order to have the
  dependencies for scim-qtimm-32bit available.
* Mon Oct  8 2012 aj@suse.de
- Run SuSEconfig.scim as part of post install only.
* Wed Sep 12 2012 hillwood@linuxfans.org
- update to 1.4.14，upstream have added gtk3 support
- enable gtk3 ,qt3 and qt4 option
* Tue Jun 12 2012 tiwai@suse.de
- Build with gtk2 instead of gtk3;
  gtk3 breaks too many input-engine subpackages!!
* Wed Jun  6 2012 i@marguerite.su
- versioned obsoletes.
- fdupes.
  * but it's useless on this package.
* Sat Jun  2 2012 i@marguerite.su
- fix build sle11.
* Sat Jun  2 2012 i@marguerite.su
- update to 1.4.13:the installation procedure adapted.
- add ld-version-script.patch:fix im-scim-version-script build.
- add CXXFLAGS to detect gettex in gcc4.7
- fix rpmlint warnings as I can.
- run format_spec_file and spec-cleaner.
- drop obsolete patches.
* Sat May 12 2012 i@marguerite.su
- let scim retire as default input method in DVD by removing Provides: locale(ja;ko;zh).
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 swyear@gmail.com
- Add post scrpitlet to add scim icon to gnome 3 tray
- Use GTK_IM_MODULE="scim"
* Mon Nov 14 2011 swyear@gmail.com
- Add gtk3 support
* Fri Oct 28 2011 tiwai@suse.de
- Add the fallback to xim for GTK3 (bnc#723382)
* Mon Oct 10 2011 tiwai@suse.de
- Updated to scim-1.4.11: fix for multiple monitors, updated
  translations
- Fix registration for FireFox (bnc#723337)
- Clean up spec file
* Mon Aug  8 2011 tiwai@suse.de
- Fix baselibs.conf to update GTK immodule cache properly for
  scim-32bit, too.
* Wed Mar  9 2011 tiwai@suse.de
- Fix post scripts to use new gtk2_immodule_* macros (bnc#678080)
* Thu Nov 11 2010 coolo@novell.com
- own parent directories
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Jun  9 2009 tiwai@suse.de
- fix crash with Firefox and glibc-2.10, due to a mysterious
  broken free() detection with setpwent().
* Thu Jun  4 2009 tiwai@suse.de
- fix build with gcc4.4
- fix build errors on older distros due to lack libexpat
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Dec  3 2008 mfabian@suse.de
- bnc#455976: rely on the autostart mechanism for skim only
  in case of KDE3, not KDE4. Otherwise input in applications
  using XIM will not work.
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit in baselibs.conf (bnc#354164).
* Tue Oct  7 2008 mfabian@suse.de
- don’t use libtoolize and autoreconf for openSUSE > 11.0
  (fixes build in Factory).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Aug  2 2007 mfabian@suse.de
- update to 1.4.7:
  • Error handling bug in scim::Socket non-blocking read and
    write methods.
  • High power consumption issue caused by X11 FrontEnd.
- remove bugzilla-221326-ltc27940-revert.patch (now upstream).
- remove #!/bin/sh from SuSEconfig.scim because RPMLINT complains.
* Fri May  4 2007 mfabian@suse.de
- Bugzilla #221326: the original patch proposed by IBM slipped
  in upstream. Revert it because of its side effects.
* Wed May  2 2007 mfabian@suse.de
- Bugzilla #248159: fix scim-laucher segfault when scim-launcher
  is already running. Patch by Peng Wu <pwu@novell.com>.
* Mon Apr 23 2007 mfabian@suse.de
- update to 1.4.6.
  • Fixed BSD Support
  • Added jp106 keyboard support, thanks Ryo Dairiki and
    Takuro Ashie.
  • Fixed Lookup table flickering in some gtk applications.
  • Adjusts the position of toolbar according to the size of
    current work area.
  • Uses GtkEventBox instead of GtkButton in tray icon.
  • Doesn't set locale if it's already set.
  • Added Dutch translation. Thanks Ronald Stroethoff.
- remove do-not-return-random-data-in-a-function.patch
  (included upstream).
- remove language-name.patch, bugzilla-224796-compose-key-fix.patch
  bugzilla-232014-fix-for-openoffice.patch
  (were from upstream CVS).
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build static libraries (#238552).
- Removed gconf2 support - gconf module does not exist any more.
* Thu Jan 25 2007 mfabian@suse.de
- disable the patch for bugzilla #221326 because of the side
  effects it causes.
- determine gnome_prefix automatically
- don't try to edit the list of UTF-8 locales into scim.schemas,
  this file doesn't exist anymore.
* Wed Jan 10 2007 mfabian@suse.de
- Bugzilla #232014: OpenOffice requires the preedit caret to be
  at the end of the preedit string or weird behaviour will
  occur. Fixed by Zhe Su <zsu@novell.com>.
- Gnome has moved to /usr for openSUSE > 10.2.
* Thu Nov 30 2006 zsu@suse.de
- Bugzilla 224796:
  Fixed a wrong compose key entry in scim_compose_key_data.h,
  which causes en-dash and em-dash couldn't be inputted correctly.
* Fri Nov 17 2006 mfabian@suse.de
- Bugzilla #221326, LTC27940:
  "SCIM commits each input unexpectedly if two ICs were created".
* Thu Nov  2 2006 zsu@suse.de
- Handle the language names such as "zh-cn" correctly.
* Tue Oct 10 2006 mfabian@suse.de
- update to 1.4.5.
- remove the following patches because they are included in the 1.4.5
  release:
  • bugzilla-159436-x11-frontend-helper-operation.patch
  • bugzilla-163522-xim-server-returns-unexpected-data.patch
  • bugzilla-185176-transfer-empty-lookuptable.patch
  • bugzilla-198374-gtk-immodule-bug-for-non-standard-gtk-application.patch
* Thu Aug 10 2006 mfabian@suse.de
- Bugzilla #198374: "SCIM gtk immodule bug for non-standard gtk
  application": add patch by the author Zhe Su <zsu@novell.com>.
* Thu Jun 15 2006 zsu@suse.de
- Bugzilla #185176: Fixed a bug which prevents empty LookupTable
  from being handled correctly by scim::Transaction.
* Mon Apr 10 2006 mfabian@suse.de
- Bugzilla #87443: add "Hangul" to the SCIM Trigger keys.
  See also: http://librarian.launchpad.net/1914454/scim_config.diff
  https://launchpad.net/distros/ubuntu/+source/scim/+bug/37687
* Fri Apr  7 2006 mfabian@suse.de
- Bugzilla #163522: SCIM XIM server returns unexpected data.
* Mon Mar 20 2006 zsu@suse.de
- Bugzilla #159436: fix x11 frontend to enable communication between
  un-focused IC and helper module.
* Tue Mar 14 2006 mfabian@suse.de
- Bugzilla #157814: make SuSEconfig.scim executable.
* Sat Mar  4 2006 zsu@suse.de
- Upgrade to the latest cvs head to fix the following issues [#154308]
  - Fixed a NULL pointer bug in scim_imengine_setup.cpp, which causes
    GTK-CRITICAL issue when launching scim-setup.
  - Rename language name "Panjabi" to "Punjabi".
  - Add 4 new languange names that required by m17n 1.3.0
  - Fixed a bug in rawcode engine which prevents from inputting some
    code point.
* Tue Feb 28 2006 mfabian@suse.de
- Bugzilla #153791: use ';' in locale(ja;ko;zh).
* Thu Feb 23 2006 mfabian@suse.de
- Bugzilla #149536: add /opt/kde3/bin to path in
  /etc/X11/xim.d/scim.
- add Provides: locale(ja,ko,zh).
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 zsu@suse.de
- Move the page up/down buttons of horizontal lookup table
  back to right side.
- Fix some compile warnings.
* Thu Jan 12 2006 mfabian@suse.de
- update to 1.4.4.
* Fri Aug 19 2005 mfabian@suse.de
- Bugzilla #105319: make /FrontEnd/X11/Dynamic = false the
  default again to make sure that Compose works always.
- Bugzilla #105193: add "Zenkaku_Hankaku" to
  /Hotkeys/FrontEnd/Trigger (this is the trigger key used MS IME
  for Japanese).
* Thu Aug 18 2005 mfabian@suse.de
- Bugzilla #105319: fix typo in our patch of the default config
  (Shift+space instead of Shift+Space).
* Mon Aug 15 2005 mfabian@suse.de
- fix a bug of the focus ic handling by updating to
  scim 1.4.1.20050815 (CVS HEAD).
* Tue Aug  9 2005 mfabian@suse.de
- Bugzilla #97962 and Bugzilla #10304: update to scim 1.4.1.
  (see comment #9 in Bugzilla #10304).
- make "/FrontEnd/SharedInputMethod = true" the default.
* Wed Jul 27 2005 mfabian@suse.de
- Bugzilla #85416: add configure option "--enable-ld-version-script"
* Mon Jul 18 2005 mfabian@suse.de
- update to 1.4.0.
  + add SuSEconfig.scim (by Zhe Su) to synchronize the scim
    keyboard setting with the system wide keyboard setting.
  + add patch from CVS to support three more keyboard layouts.
* Wed Jul  6 2005 mfabian@suse.de
- update to 1.3.3.
  (Fix for Bugzilla #74356 now included).
* Tue Jul  5 2005 mfabian@suse.de
- Bugzilla #74356: "Clicking KDE printer icon crashes"
  fixed with lots of help by Michael Matz <matz@suse.de>.
* Mon Jul  4 2005 mfabian@suse.de
- update to 1.3.2.
* Mon Jun 20 2005 mfabian@suse.de
- update to 1.3.1.
* Thu Jun  2 2005 mfabian@suse.de
- update to 1.3.0.
- remove included patches (warnings.patch, gcc4-friends.patch).
* Sun May 22 2005 aj@suse.de
- Fix for GCC 4 friends conformance.
* Tue May 10 2005 mfabian@suse.de
- update to 1.2.2.
- Czech translations are included upstream now, remove patch.
* Wed Mar 30 2005 mfabian@suse.de
- fix some compilation warnings.
* Thu Mar 10 2005 mfabian@suse.de
- add Czech translations done by Klara Cihlarova <cihlarov@suse.cz>.
* Mon Feb 28 2005 mfabian@suse.de
- update to 1.2.0.
* Wed Feb 23 2005 mfabian@suse.de
- Bugzilla #66295: make it possible to use scim-config-agent to
  trigger a reload of SCIM's configuration (from the upstream
  author Zhe Su <zsu@novell.com>.
- update French translations
* Tue Feb 22 2005 mfabian@suse.de
- fix typo in  /etc/X11/xim.d/scim.
* Mon Feb 21 2005 mfabian@suse.de
- create start script /etc/X11/xim.d/scim and symlinks in
  locale specific subdirectories.
* Fri Feb  4 2005 adrian@suse.de
- update to 1.1.3
* Mon Jan 24 2005 mfabian@suse.de
- update to 1.1.2.
* Mon Jan 10 2005 mfabian@suse.de
- update to 1.1.0.20050110
* Thu Dec 30 2004 mfabian@suse.de
- update to 1.0.2.
- remove reduce-default-debug-output.patch (Zhe Su has implemented
  a better solution in 1.0.2 now).
* Mon Oct  4 2004 mfabian@suse.de
- Bugzilla #46565: reduce default debug output of scim.
- Bugzilla #46365 comment #20: Set preedit caret when updating
  preedit string.
* Wed Sep 29 2004 mfabian@suse.de
- make OnTheSpot input style the default for XIM.
* Tue Sep 21 2004 mfabian@suse.de
- update to 1.0.1
  - Added missing assignment for SCIM_BUILD_GTK_UTILS variable in
    configure.ac
  - Call focus_out when turnning off input method in gtkimmodule.
  - Fixed gtk2 binary compatibility issue. Now scim binary compiled
    against gtk2-2.2.x can be used with gtk2-2.4.x.
* Mon Sep 20 2004 mfabian@suse.de
- add bugfix-patch received from author (Zhe Su).
- add "Requires: gtk2 >= 2.2.0, gtk2 < 2.4.0" for SuSE 9.1.
* Sat Sep  4 2004 mfabian@suse.de
- make scim the default for ja, ko, zh_CN, zh_TW, and zh_HK
  when using GTK_IM_MODULE.
* Sat Sep  4 2004 mfabian@suse.de
- update to 1.0.0.
* Fri Sep  3 2004 mfabian@suse.de
- use "Control+space,Shift+space" as the default for
  /FrontEnd/Keys/Trigger instead of only "Control+space".
  Users of kinput2, ami, ... are used to Shift+Space and may
  not expect "Control+Space".
* Mon Aug 30 2004 mfabian@suse.de
- update to 0.99.9.
  (German translations available now, startup problem in ~/.xim
  is fixed).
* Wed Aug 25 2004 mfabian@suse.de
- update to 0.99.8.
- Bugzilla #44155: add /usr/bin/touch to PreReq:.
- enable all UTF-8 locales again in /etc/scim/global, this
  should work now, Zhe Su fixed a bug in IMdkit.
* Sat Aug 21 2004 mfabian@suse.de
- add 64bit.patch received from Zhe Su to fix crash of scim-setup
  on x86_64 when clicking on the top-level items in the tree
  on the left side.
* Fri Aug 20 2004 mfabian@suse.de
- update to 0.99.7.
* Wed Aug 18 2004 mfabian@suse.de
- Bugzilla #43802: add 64bit.patch received from
  Zhe Su <zsu@novell.com> which fixes this bug.
* Fri Aug 13 2004 mfabian@suse.de
- update to 0.99.6 final.
* Thu Aug 12 2004 mfabian@suse.de
- update to 0.99.6 (CVS)
  (includes my 64bit.patch to fix the segmentation fault on x86_64)
* Thu Aug  5 2004 mfabian@suse.de
- update to 0.99.2.
- merge scim-gtk2-immodule, scim-config-socket, scim-server-socket,
  scim-config-gconf, and scim-frontend-socket subpackages into
  scim and scim-devel (the upstream author made that change I
  think it's better that way too).
* Tue May 11 2004 sbrabec@suse.cz
- PreReq moved to proper subpackage.
* Tue May 11 2004 sbrabec@suse.cz
- Fixed gconftool-2 prerequirements.
* Tue Apr 27 2004 mfabian@suse.de
- update to 0.9.6
- remove scim-0.9.1-fix.patch (included now).
- set text DOMAIN to "scim" to make the .mo files install correctly
- mv scim-im.so to /opt/gnome/%%_lib/gtk-2.0/immodules/im-scim.so
  instead of /opt/gnome/%%_lib/gtk-2.0/2.3.5/immodules/im-scim.so
* Fri Apr  2 2004 mfabian@suse.de, zsu@novell.com
- add patch received by author which fixes a problem with the gtk
  help dialog.
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Fri Feb 27 2004 mfabian@suse.de
- don't enable all UTF-8 locales, unfortunately this still doesn't
  work.
* Thu Feb 26 2004 mfabian@suse.de
- update to 0.9.1.
- remove max-config-line-length.patch, included upstream.
* Thu Feb  5 2004 mfabian@suse.de
- don't make SCIM the default GTK input method for all languages,
  only for "zh".
- increase maximum allowed line length in config file.
* Tue Dec  9 2003 mfabian@suse.de
- update to 0.8.2.
- remove subpackages scim-frontend-x11, scim-server-rawcode,
  scim-server-table, scim-config-simple (these are merged into
  the main scim packages upstream, it's better use the same
  structure in the SUSE packages as upstream).
* Wed Oct 22 2003 sbrabec@suse.cz
- Use SuSE standard gconf schema installation.
* Fri Sep  5 2003 mfabian@suse.de
- don't try to call in gtk-query-immodules-2.0 in %%post and
  %%postun, just trigger a run of SuSEconfig.gtk2
  which will then call gtk-query-immodules-2.0. See also
  Bugzilla #29417.
* Wed Aug 20 2003 mfabian@suse.de
- remove "Requires: gconf2 >= 1.1.10"
* Fri Aug 15 2003 adrian@suse.de
- add Categories
* Sun Aug  3 2003 ro@suse.de
- gtk has been moved to /opt/gnome
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jul  4 2003 mfabian@suse.de
- new package: version 0.5.0.
- adapt .spec file for SuSE.
- remove scim-suite subpackage, it contains the same files as
  some other sub-packages and is only intended to make it easier
  for the user to install the basic stuff to use SCIM without
  having to think which sub-packages to install. But this can be
  done by language specific selections, having an extra package
  duplicating contents of other packages just wastes space on
  the CDs.
* Thu Jun 19 2003 James Su <suzhe@turbolinux.com.cn>
- updated to include scim-setup and its modules.
* Thu Apr  3 2003 James Su <suzhe@turbolinux.com.cn>
- added suite package, which includes all necessary components of SCIM.
* Tue Mar 25 2003 James Su <suzhe@turbolinux.com.cn>
- updated to v0.4.0
* Wed Feb 26 2003 James Su <suzhe@turbolinux.com.cn>
- implemented dynamic adjust feature for generic table module.
- fixed key handling bug in generic table module.
* Mon Feb 10 2003 James Su <suzhe@turbolinux.com.cn>
- Replaced highlight_start and highlight_end in scim_server
  and scim_frontend with AttributeList (scim_attributes.h)
- Moved icons/* to data/icons and gtkstringview.* to
  utils/
* Thu Jan  2 2003 James Su <suzhe@turbolinux.com.cn>
- updated configure.ac and Makefile.am
- ready to release 0.3.0
* Tue Nov 12 2002 James Su <suzhe@turbolinux.com.cn>
- merged signal system from libinti.
- implemented namespace scim.
- implemented referenced object.
- version 0.3.0
* Tue Nov  5 2002 James Su <suzhe@turbolinux.com.cn>
- minor fixes for table IM module.
* Mon Nov  4 2002 James Su <suzhe@turbolinux.com.cn>
- More IMdkit memory leak fixes.
- Table input method bugfixes.
- version 0.2.2
* Fri Nov  1 2002 James Su <suzhe@turbolinux.com.cn>
- improved table input method.
- actually fixed the memleaks within IMdkit.
- pumped the version to 0.2.1
* Thu Oct 31 2002 James Su <suzhe@turbolinux.com.cn>
- fixed some memory leaks in IMdkit
- reduced memory usage.
- upgraded to libtool-1.4.3
* Tue Oct 29 2002 James Su <suzhe@turbolinux.com.cn>
- finished Generic Table input server module.
- fixed several bugs in scim-lib.
* Thu Oct 10 2002 James Su <suzhe@turbolinux.com.cn>
- used gettext to support i18n message.
- added release info to lib name.
* Mon Sep 30 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.4
- added Embedded Lookup Table style into X11 FrontEnd.
- use wchar_t instead of unsigned long if __STDC_ISO_10646__ defined.
* Sun Sep 22 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.3
- config button of X11 FrontEnd was disabled.
* Fri Sep  6 2002 James Su <suzhe@turbolinux.com.cn>
- simplified the utilities and lookup table interface.
* Wed Aug 21 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.2
- added configuration options to disable modules.
- enhanced X11 FrontEnd.
* Sun Aug 11 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.1
- X11 FrontEnd was enhanced.
* Sat Aug 10 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.0
- many bugfixes.
- Help window of X11 FrontEnd was implemented.
- scim can exit cleanly.
* Fri Aug  2 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.13.
- Minor bugfixes.
* Mon Jul 29 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.12.
- Minor bugfixes.
* Sun Jul 28 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.11.
- Minor bugfixes.
* Sun Jul 21 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.10.
- Added Simple Config module.
* Sat Jun 22 2002 James Su <suzhe@turbolinux.com.cn>
- first public release of SCIM.
